==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/IdentityProvidersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * The configuration settings of each of the identity providers used to configure ContainerApp Service Authentication/Authorization.
 * @property apple The configuration settings of the Apple provider.
 * @property azureActiveDirectory The configuration settings of the Azure Active directory provider.
 * @property azureStaticWebApps The configuration settings of the Azure Static Web Apps provider.
 * @property customOpenIdConnectProviders The map of the name of the alias of each custom Open ID Connect provider to the
 * configuration settings of the custom Open ID Connect provider.
 * @property facebook The configuration settings of the Facebook provider.
 * @property gitHub The configuration settings of the GitHub provider.
 * @property google The configuration settings of the Google provider.
 * @property twitter The configuration settings of the Twitter provider.
 */
public data class IdentityProvidersArgs(
    public val apple: Output<AppleArgs>? = null,
    public val azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null,
    public val azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null,
    public val customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null,
    public val facebook: Output<FacebookArgs>? = null,
    public val gitHub: Output<GitHubArgs>? = null,
    public val google: Output<GoogleArgs>? = null,
    public val twitter: Output<TwitterArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.IdentityProvidersArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.IdentityProvidersArgs =
        com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder()
            .apple(apple?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .azureActiveDirectory(
                azureActiveDirectory?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .azureStaticWebApps(
                azureStaticWebApps?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customOpenIdConnectProviders(
                customOpenIdConnectProviders?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value.let({ args0 -> args0.toJava() })) }).toMap()
                }),
            )
            .facebook(facebook?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gitHub(gitHub?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .google(google?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .twitter(twitter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IdentityProvidersArgs].
 */
@PulumiTagMarker
public class IdentityProvidersArgsBuilder internal constructor() {
    private var apple: Output<AppleArgs>? = null

    private var azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null

    private var azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null

    private var customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null

    private var facebook: Output<FacebookArgs>? = null

    private var gitHub: Output<GitHubArgs>? = null

    private var google: Output<GoogleArgs>? = null

    private var twitter: Output<TwitterArgs>? = null

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("raybeoiwwyiopcub")
    public suspend fun apple(`value`: Output<AppleArgs>) {
        this.apple = value
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("eeprvnuihibpgntn")
    public suspend fun azureActiveDirectory(`value`: Output<AzureActiveDirectoryArgs>) {
        this.azureActiveDirectory = value
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("fknsxfumnjfhxomf")
    public suspend fun azureStaticWebApps(`value`: Output<AzureStaticWebAppsArgs>) {
        this.azureStaticWebApps = value
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("fjkjtldceixbkpbm")
    public suspend
    fun customOpenIdConnectProviders(`value`: Output<Map<String, CustomOpenIdConnectProviderArgs>>) {
        this.customOpenIdConnectProviders = value
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("etvhxuvqlxsujyll")
    public suspend fun facebook(`value`: Output<FacebookArgs>) {
        this.facebook = value
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("cjjuknecvpsudfkf")
    public suspend fun gitHub(`value`: Output<GitHubArgs>) {
        this.gitHub = value
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("ayqrbeibbvqivtae")
    public suspend fun google(`value`: Output<GoogleArgs>) {
        this.google = value
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("pkiqyymvmgmxeths")
    public suspend fun twitter(`value`: Output<TwitterArgs>) {
        this.twitter = value
    }

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("wapmodtowatvsbpd")
    public suspend fun apple(`value`: AppleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apple = mapped
    }

    /**
     * @param argument The configuration settings of the Apple provider.
     */
    @JvmName("tryugcmdagxnpojv")
    public suspend fun apple(argument: suspend AppleArgsBuilder.() -> Unit) {
        val toBeMapped = AppleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apple = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("aidfrxdxsqrujejl")
    public suspend fun azureActiveDirectory(`value`: AzureActiveDirectoryArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureActiveDirectory = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active directory provider.
     */
    @JvmName("dydbtxgncnmbwfyf")
    public suspend
    fun azureActiveDirectory(argument: suspend AzureActiveDirectoryArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureActiveDirectory = mapped
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("htplofosgryxvwqr")
    public suspend fun azureStaticWebApps(`value`: AzureStaticWebAppsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureStaticWebApps = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("lgxrwiabbknicfmj")
    public suspend
    fun azureStaticWebApps(argument: suspend AzureStaticWebAppsArgsBuilder.() -> Unit) {
        val toBeMapped = AzureStaticWebAppsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureStaticWebApps = mapped
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("fffnnbeugxwhhbmy")
    public suspend
    fun customOpenIdConnectProviders(`value`: Map<String, CustomOpenIdConnectProviderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param argument The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("welofwgtefepoejq")
    public suspend fun customOpenIdConnectProviders(
        vararg
        argument: Pair<String, suspend CustomOpenIdConnectProviderArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                CustomOpenIdConnectProviderArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param values The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("qtakgjwvycvmkvfx")
    public fun customOpenIdConnectProviders(
        vararg
        values: Pair<String, CustomOpenIdConnectProviderArgs>,
    ) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("dmecyskkctyiajth")
    public suspend fun facebook(`value`: FacebookArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.facebook = mapped
    }

    /**
     * @param argument The configuration settings of the Facebook provider.
     */
    @JvmName("yfoegqnjjehlbevy")
    public suspend fun facebook(argument: suspend FacebookArgsBuilder.() -> Unit) {
        val toBeMapped = FacebookArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.facebook = mapped
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("pkyiowrbrhulgvfn")
    public suspend fun gitHub(`value`: GitHubArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gitHub = mapped
    }

    /**
     * @param argument The configuration settings of the GitHub provider.
     */
    @JvmName("yybrjqpydkpysyfa")
    public suspend fun gitHub(argument: suspend GitHubArgsBuilder.() -> Unit) {
        val toBeMapped = GitHubArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gitHub = mapped
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("smlloneoqcaoalkl")
    public suspend fun google(`value`: GoogleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.google = mapped
    }

    /**
     * @param argument The configuration settings of the Google provider.
     */
    @JvmName("ikcuisytpryecppg")
    public suspend fun google(argument: suspend GoogleArgsBuilder.() -> Unit) {
        val toBeMapped = GoogleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.google = mapped
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("okvypmyxvlauaxjq")
    public suspend fun twitter(`value`: TwitterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.twitter = mapped
    }

    /**
     * @param argument The configuration settings of the Twitter provider.
     */
    @JvmName("xsluwleyqovtknhx")
    public suspend fun twitter(argument: suspend TwitterArgsBuilder.() -> Unit) {
        val toBeMapped = TwitterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.twitter = mapped
    }

    internal fun build(): IdentityProvidersArgs = IdentityProvidersArgs(
        apple = apple,
        azureActiveDirectory = azureActiveDirectory,
        azureStaticWebApps = azureStaticWebApps,
        customOpenIdConnectProviders = customOpenIdConnectProviders,
        facebook = facebook,
        gitHub = gitHub,
        google = google,
        twitter = twitter,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/IdentityProvidersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * The configuration settings of each of the identity providers used to configure ContainerApp Service Authentication/Authorization.
 * @property apple The configuration settings of the Apple provider.
 * @property azureActiveDirectory The configuration settings of the Azure Active directory provider.
 * @property azureStaticWebApps The configuration settings of the Azure Static Web Apps provider.
 * @property customOpenIdConnectProviders The map of the name of the alias of each custom Open ID Connect provider to the
 * configuration settings of the custom Open ID Connect provider.
 * @property facebook The configuration settings of the Facebook provider.
 * @property gitHub The configuration settings of the GitHub provider.
 * @property google The configuration settings of the Google provider.
 * @property twitter The configuration settings of the Twitter provider.
 */
public data class IdentityProvidersArgs(
    public val apple: Output<AppleArgs>? = null,
    public val azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null,
    public val azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null,
    public val customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null,
    public val facebook: Output<FacebookArgs>? = null,
    public val gitHub: Output<GitHubArgs>? = null,
    public val google: Output<GoogleArgs>? = null,
    public val twitter: Output<TwitterArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.IdentityProvidersArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.IdentityProvidersArgs =
        com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder()
            .apple(apple?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .azureActiveDirectory(
                azureActiveDirectory?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .azureStaticWebApps(
                azureStaticWebApps?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customOpenIdConnectProviders(
                customOpenIdConnectProviders?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value.let({ args0 -> args0.toJava() })) }).toMap()
                }),
            )
            .facebook(facebook?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gitHub(gitHub?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .google(google?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .twitter(twitter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IdentityProvidersArgs].
 */
@PulumiTagMarker
public class IdentityProvidersArgsBuilder internal constructor() {
    private var apple: Output<AppleArgs>? = null

    private var azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null

    private var azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null

    private var customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null

    private var facebook: Output<FacebookArgs>? = null

    private var gitHub: Output<GitHubArgs>? = null

    private var google: Output<GoogleArgs>? = null

    private var twitter: Output<TwitterArgs>? = null

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("pgashrgxckvbodlx")
    public suspend fun apple(`value`: Output<AppleArgs>) {
        this.apple = value
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("yfjklsxrcetgpymy")
    public suspend fun azureActiveDirectory(`value`: Output<AzureActiveDirectoryArgs>) {
        this.azureActiveDirectory = value
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("mnwfaewdcqdbcngu")
    public suspend fun azureStaticWebApps(`value`: Output<AzureStaticWebAppsArgs>) {
        this.azureStaticWebApps = value
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("nkkywpofrsgocbjp")
    public suspend
    fun customOpenIdConnectProviders(`value`: Output<Map<String, CustomOpenIdConnectProviderArgs>>) {
        this.customOpenIdConnectProviders = value
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("eugxnhmyaioegmhm")
    public suspend fun facebook(`value`: Output<FacebookArgs>) {
        this.facebook = value
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("fxgncevudjsmetqc")
    public suspend fun gitHub(`value`: Output<GitHubArgs>) {
        this.gitHub = value
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("gmtreflavllcltjf")
    public suspend fun google(`value`: Output<GoogleArgs>) {
        this.google = value
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("ctcxmoocbyuvitox")
    public suspend fun twitter(`value`: Output<TwitterArgs>) {
        this.twitter = value
    }

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("yahcavdmoqbvokaw")
    public suspend fun apple(`value`: AppleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apple = mapped
    }

    /**
     * @param argument The configuration settings of the Apple provider.
     */
    @JvmName("rmmgqwwfpivldftx")
    public suspend fun apple(argument: suspend AppleArgsBuilder.() -> Unit) {
        val toBeMapped = AppleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apple = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("eilderswjavolprt")
    public suspend fun azureActiveDirectory(`value`: AzureActiveDirectoryArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureActiveDirectory = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active directory provider.
     */
    @JvmName("bngalqbbiwcrrjdo")
    public suspend
    fun azureActiveDirectory(argument: suspend AzureActiveDirectoryArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureActiveDirectory = mapped
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("kblralbovnakhcct")
    public suspend fun azureStaticWebApps(`value`: AzureStaticWebAppsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureStaticWebApps = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("sdtwaaylthtjdbxf")
    public suspend
    fun azureStaticWebApps(argument: suspend AzureStaticWebAppsArgsBuilder.() -> Unit) {
        val toBeMapped = AzureStaticWebAppsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureStaticWebApps = mapped
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("qghgutnwwqmpnacn")
    public suspend
    fun customOpenIdConnectProviders(`value`: Map<String, CustomOpenIdConnectProviderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param argument The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("hjxcruknnkghupit")
    public suspend fun customOpenIdConnectProviders(
        vararg
        argument: Pair<String, suspend CustomOpenIdConnectProviderArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                CustomOpenIdConnectProviderArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param values The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("irsotyjikodkiuit")
    public fun customOpenIdConnectProviders(
        vararg
        values: Pair<String, CustomOpenIdConnectProviderArgs>,
    ) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("arboqdlekkvmcsdk")
    public suspend fun facebook(`value`: FacebookArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.facebook = mapped
    }

    /**
     * @param argument The configuration settings of the Facebook provider.
     */
    @JvmName("xwsrkxtakqiqpmhy")
    public suspend fun facebook(argument: suspend FacebookArgsBuilder.() -> Unit) {
        val toBeMapped = FacebookArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.facebook = mapped
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("gvvslggpddmouenu")
    public suspend fun gitHub(`value`: GitHubArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gitHub = mapped
    }

    /**
     * @param argument The configuration settings of the GitHub provider.
     */
    @JvmName("rwuatsvbxefpwurt")
    public suspend fun gitHub(argument: suspend GitHubArgsBuilder.() -> Unit) {
        val toBeMapped = GitHubArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gitHub = mapped
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("lllrrdcfaboqwfky")
    public suspend fun google(`value`: GoogleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.google = mapped
    }

    /**
     * @param argument The configuration settings of the Google provider.
     */
    @JvmName("vfpuiweoqcjagqaf")
    public suspend fun google(argument: suspend GoogleArgsBuilder.() -> Unit) {
        val toBeMapped = GoogleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.google = mapped
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("ngfecxtlbiwbyfai")
    public suspend fun twitter(`value`: TwitterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.twitter = mapped
    }

    /**
     * @param argument The configuration settings of the Twitter provider.
     */
    @JvmName("cnjnpfugiccocnep")
    public suspend fun twitter(argument: suspend TwitterArgsBuilder.() -> Unit) {
        val toBeMapped = TwitterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.twitter = mapped
    }

    internal fun build(): IdentityProvidersArgs = IdentityProvidersArgs(
        apple = apple,
        azureActiveDirectory = azureActiveDirectory,
        azureStaticWebApps = azureStaticWebApps,
        customOpenIdConnectProviders = customOpenIdConnectProviders,
        facebook = facebook,
        gitHub = gitHub,
        google = google,
        twitter = twitter,
    )
}
